@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2001-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2001-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -45,7 +45,7 @@ function _delete($task_id, $tasklist_id)
     }
 
     /* Return to the last page or to the task list. */
-    if ($url = Horde_Util::getFormData('url')) {
+    if ($url = Horde::verifySignedUrl(Horde_Util::getFormData('url'))) {
         header('Location: ' . $url);
         exit;
     }
